@@ -1,4 +1,4 @@
-# Copyright (C) 2021-2022 Greenbone Networks GmbH
+# Copyright (C) 2021-2022 Greenbone AG
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 #
@@ -23,6 +23,14 @@ from typing import Any, Dict, Iterable, Optional
 
 
 class PullRequestState(Enum):
+    """
+    State of a pull request
+
+    Attributes:
+        OPEN: The pull request is open
+        CLOSED: The pull request is closed
+    """
+
     OPEN = "open"
     CLOSED = "closed"
 
@@ -40,6 +48,10 @@ class Label:
 class Ref:
     """
     A git branch reference
+
+    Attributes:
+        name: Name of the git branch reference for example main
+        sha: Git commit ID of the reference
     """
 
     name: str
@@ -52,6 +64,16 @@ class GitHubPullRequestEvent:
     Event data of a GitHub Pull Request
 
     https://docs.github.com/en/developers/webhooks-and-events/webhooks/webhook-events-and-payloads#pull_request
+
+    Attributes:
+        draft: True if the pull request is a draft
+        number: ID of the pull request
+        labels: Labels attached to the pull request
+        title: Title of the pull request
+        merged: True if the pull request is already merged
+        state: State of the pull request (open, closed)
+        base: Base reference of the pull request (target branch)
+        head: Head reference of the pull request (source branch)
     """
 
     draft: Optional[bool]
@@ -64,6 +86,13 @@ class GitHubPullRequestEvent:
     head: Ref
 
     def __init__(self, pull_request_data: Dict[str, Any]):
+        """
+        Derive the pull request information from the pull request data of a
+        GitHub event.
+
+        Args:
+            pull_request_data: JSON based pull request information as dict
+        """
         data = pull_request_data or {}
 
         self.draft = data.get("draft")
@@ -88,11 +117,20 @@ class GitHubEvent:
 
     The JSON data for the events is specified at
     https://docs.github.com/en/developers/webhooks-and-events/webhooks/webhook-events-and-payloads
+
+    Attributes:
+        pull_request: Information about the pull request
     """
 
     pull_request: GitHubPullRequestEvent
 
     def __init__(self, event_path: Path):
+        """
+        Loads the event data from the passed path
+
+        Args:
+            event_path: Path to the event data
+        """
         content = event_path.read_text(encoding="utf-8")
         self._event_data = json.loads(content) if content else {}
         pull_request_data = self._event_data.get("pull_request")
