@@ -184,6 +184,8 @@ class PEP440Version(Version):
         return cls.from_string(str(version))
 
     def __eq__(self, other: Any) -> bool:
+        if other is None:
+            return False
         if isinstance(other, str):
             # allow to compare against "current" for now
             return False
@@ -194,6 +196,8 @@ class PEP440Version(Version):
         return self._version == other._version
 
     def __ne__(self, other: Any) -> bool:
+        if other is None:
+            return True
         if isinstance(other, str):
             # allow to compare against "current" for now
             return True
@@ -203,6 +207,13 @@ class PEP440Version(Version):
             other = self.from_version(other)
         return self._version != other._version
 
+    def __gt__(self, other: Any) -> bool:
+        if not isinstance(other, Version):
+            raise ValueError(f"Can't compare {type(self)} with {type(other)}")
+        if not isinstance(other, type(self)):
+            other = self.from_version(other)
+        return self._version > other._version
+
     def __str__(self) -> str:
         return str(self._version)
 
@@ -391,3 +402,4 @@ class PEP440VersioningScheme(VersioningScheme):
 
     version_calculator_cls = PEP440VersionCalculator
     version_cls = PEP440Version
+    name = "PEP440"
