@@ -132,6 +132,10 @@ class Version(ABC):
     def __ne__(self, other: Any) -> bool:
         pass
 
+    @abstractmethod
+    def __gt__(self, other: Any) -> bool:
+        pass
+
     @abstractmethod
     def __str__(self) -> str:
         """A string representation of the version"""
@@ -152,6 +156,9 @@ class VersionUpdate:
     If previous and new are equal the version was not updated and changed_files
     should be empty.
 
+    If there is no previous version for example in an initial release previous
+    should be None.
+
     Example:
         .. code-block:: python
 
@@ -165,6 +172,10 @@ class VersionUpdate:
             )
     """
 
-    previous: Version
+    previous: Optional[Version]
     new: Version
     changed_files: list[Path] = field(default_factory=list)
+
+    @property
+    def is_update(self) -> bool:
+        return self.previous != self.new
