@@ -39,22 +39,9 @@ from pontos.updateheader.updateheader import _parse_args as parse_args
 from pontos.updateheader.updateheader import _update_file as update_file
 from pontos.updateheader.updateheader import main
 
-HEADER = """# Copyright (C) {date} Greenbone AG
+HEADER = """# SPDX-FileCopyrightText: {date} Greenbone AG
 #
-# SPDX-License-Identifier: AGPL-3.0-or-later
-#
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Affero General Public License as
-# published by the Free Software Foundation, either version 3 of the
-# License, or (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU Affero General Public License for more details.
-#
-# You should have received a copy of the GNU Affero General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>."""
+# SPDX-License-Identifier: AGPL-3.0-or-later"""
 
 
 class Terminal(ConsoleTerminal):
@@ -71,7 +58,7 @@ class UpdateHeaderTestCase(TestCase):
         self.path = Path(__file__).parent
 
         self.regex = re.compile(
-            "[Cc]opyright.*?(19[0-9]{2}|20[0-9]{2}) "
+            "(SPDX-FileCopyrightText:|[Cc]opyright).*?(19[0-9]{2}|20[0-9]{2}) "
             f"?-? ?(19[0-9]{{2}}|20[0-9]{{2}})? ({self.args.company})"
         )
 
@@ -136,12 +123,41 @@ class UpdateHeaderTestCase(TestCase):
         self.assertFalse(found)
         self.assertIsNone(match)
 
+    def test_find_spdx_copyright(self):
+        test_line = "# SPDX-FileCopyrightText: 1995-2021 Greenbone AG"
+        test2_line = "# SPDX-FileCopyrightText: 1995 Greenbone AG"
+        invalid_line = (
+            "# This program is free software: "
+            "you can redistribute it and/or modify"
+        )
+
+        # Full match
+        found, match = find_copyright(regex=self.regex, line=test_line)
+        self.assertTrue(found)
+        self.assertIsNotNone(match)
+        self.assertEqual(match["creation_year"], "1995")
+        self.assertEqual(match["modification_year"], "2021")
+        self.assertEqual(match["company"], self.args.company)
+
+        # No modification Date
+        found, match = find_copyright(regex=self.regex, line=test2_line)
+        self.assertTrue(found)
+        self.assertIsNotNone(match)
+        self.assertEqual(match["creation_year"], "1995")
+        self.assertEqual(match["modification_year"], None)
+        self.assertEqual(match["company"], self.args.company)
+
+        # No match
+        found, match = find_copyright(regex=self.regex, line=invalid_line)
+        self.assertFalse(found)
+        self.assertIsNone(match)
+
     def test_add_header(self):
         expected_header = HEADER.format(date="2021") + "\n"
 
         header = add_header(
             suffix=".py",
-            licence="AGPL-3.0-or-later",
+            license_id="AGPL-3.0-or-later",
             company=self.args.company,
             year="2021",
         )
@@ -152,16 +168,16 @@ class UpdateHeaderTestCase(TestCase):
         with self.assertRaises(ValueError):
             add_header(
                 suffix=".prr",
-                licence="AGPL-3.0-or-later",
+                license_id="AGPL-3.0-or-later",
                 company=self.args.company,
                 year="2021",
             )
 
-    def test_add_header_licence_not_found(self):
+    def test_add_header_license_not_found(self):
         with self.assertRaises(FileNotFoundError):
             add_header(
                 suffix=".py",
-                licence="AAAGPL-3.0-or-later",
+                license_id="AAAGPL-3.0-or-later",
                 company=self.args.company,
                 year="2021",
             )
@@ -170,7 +186,7 @@ class UpdateHeaderTestCase(TestCase):
     def test_update_file_not_existing(self, mock_stdout):
         self.args.year = "2020"
         self.args.changed = False
-        self.args.licence = "AGPL-3.0-or-later"
+        self.args.license_id = "AGPL-3.0-or-later"
 
         term = Terminal()
 
@@ -193,10 +209,10 @@ class UpdateHeaderTestCase(TestCase):
         )
 
     @patch("sys.stdout", new_callable=StringIO)
-    def test_update_file_wrong_licence(self, mock_stdout):
+    def test_update_file_wrong_license(self, mock_stdout):
         self.args.year = "2020"
         self.args.changed = False
-        self.args.licence = "AAAGPL-3.0-or-later"
+        self.args.license_id = "AAAGPL-3.0-or-later"
 
         term = Terminal()
 
@@ -211,7 +227,7 @@ class UpdateHeaderTestCase(TestCase):
         ret = mock_stdout.getvalue()
         self.assertEqual(
             ret,
-            f"{test_file}: Licence file for "
+            f"{test_file}: License file for "
             "AAAGPL-3.0-or-later is not existing.\n",
         )
 
@@ -221,7 +237,7 @@ class UpdateHeaderTestCase(TestCase):
     def test_update_file_suffix_invalid(self, mock_stdout):
         self.args.year = "2020"
         self.args.changed = False
-        self.args.licence = "AGPL-3.0-or-later"
+        self.args.license_id = "AGPL-3.0-or-later"
 
         term = Terminal()
 
@@ -236,7 +252,7 @@ class UpdateHeaderTestCase(TestCase):
         ret = mock_stdout.getvalue()
         self.assertEqual(
             ret,
-            f"{test_file}: No licence header for the format .pppy found.\n",
+            f"{test_file}: No license header for the format .pppy found.\n",
         )
 
         test_file.unlink()
@@ -245,7 +261,7 @@ class UpdateHeaderTestCase(TestCase):
     def test_update_file_binary_file(self, mock_stdout):
         self.args.year = "2020"
         self.args.changed = False
-        self.args.licence = "AGPL-3.0-or-later"
+        self.args.license_id = "AGPL-3.0-or-later"
 
         term = Terminal()
 
@@ -279,7 +295,7 @@ class UpdateHeaderTestCase(TestCase):
     def test_update_file_changed(self, mock_stdout):
         self.args.year = "1995"
         self.args.changed = True
-        self.args.licence = "AGPL-3.0-or-later"
+        self.args.license_id = "AGPL-3.0-or-later"
 
         term = Terminal()
 
@@ -308,7 +324,7 @@ class UpdateHeaderTestCase(TestCase):
     def test_update_create_header(self, mock_stdout):
         self.args.year = "1995"
         self.args.changed = False
-        self.args.licence = "AGPL-3.0-or-later"
+        self.args.license_id = "AGPL-3.0-or-later"
 
         term = Terminal()
 
@@ -323,7 +339,7 @@ class UpdateHeaderTestCase(TestCase):
 
         ret = mock_stdout.getvalue()
         self.assertEqual(
-            f"{test_file}: Added licence header.\n",
+            f"{test_file}: Added license header.\n",
             ret,
         )
         self.assertEqual(code, 0)
@@ -334,7 +350,7 @@ class UpdateHeaderTestCase(TestCase):
     def test_update_header_in_file(self, mock_stdout):
         self.args.year = "2021"
         self.args.changed = False
-        self.args.licence = "AGPL-3.0-or-later"
+        self.args.license_id = "AGPL-3.0-or-later"
 
         term = Terminal()
 
@@ -354,11 +370,11 @@ class UpdateHeaderTestCase(TestCase):
         ret = mock_stdout.getvalue()
         self.assertEqual(
             ret,
-            f"{test_file}: Changed Licence Header "
+            f"{test_file}: Changed License Header "
             "Copyright Year None -> 2021\n",
         )
         self.assertIn(
-            "# Copyright (C) 2020-2021 Greenbone AG",
+            "# SPDX-FileCopyrightText: 2020-2021 Greenbone AG",
             test_file.read_text(encoding="utf-8"),
         )
 
@@ -368,7 +384,7 @@ class UpdateHeaderTestCase(TestCase):
     def test_update_header_ok_in_file(self, mock_stdout):
         self.args.year = "2021"
         self.args.changed = False
-        self.args.licence = "AGPL-3.0-or-later"
+        self.args.license_id = "AGPL-3.0-or-later"
 
         term = Terminal()
 
@@ -388,10 +404,10 @@ class UpdateHeaderTestCase(TestCase):
         ret = mock_stdout.getvalue()
         self.assertEqual(
             ret,
-            f"{test_file}: Licence Header is ok.\n",
+            f"{test_file}: License Header is ok.\n",
         )
         self.assertIn(
-            "# Copyright (C) 2021 Greenbone AG",
+            "# SPDX-FileCopyrightText: 2021 Greenbone AG",
             test_file.read_text(encoding="utf-8"),
         )
 
@@ -400,7 +416,7 @@ class UpdateHeaderTestCase(TestCase):
     def test_argparser_files(self):
         self.args.year = "2021"
         self.args.changed = False
-        self.args.licence = "AGPL-3.0-or-later"
+        self.args.license_id = "AGPL-3.0-or-later"
 
         args = ["-f", "test.py", "-y", "2021", "-l", "AGPL-3.0-or-later"]
 
@@ -409,12 +425,12 @@ class UpdateHeaderTestCase(TestCase):
         self.assertEqual(args.company, self.args.company)
         self.assertEqual(args.files, ["test.py"])
         self.assertEqual(args.year, self.args.year)
-        self.assertEqual(args.licence, self.args.licence)
+        self.assertEqual(args.license, self.args.license_id)
 
     def test_argparser_dir(self):
         self.args.year = "2020"
         self.args.changed = False
-        self.args.licence = "AGPL-3.0-or-later"
+        self.args.license_id = "AGPL-3.0-or-later"
 
         args = ["-d", ".", "-c", "-l", "AGPL-3.0-or-later"]
 
@@ -424,7 +440,7 @@ class UpdateHeaderTestCase(TestCase):
         self.assertEqual(args.directories, ["."])
         self.assertTrue(args.changed)
         self.assertEqual(args.year, str(datetime.datetime.now().year))
-        self.assertEqual(args.licence, self.args.licence)
+        self.assertEqual(args.license, self.args.license_id)
 
     def test_get_exclude_list(self):
         # Try to find the current file from two directories up...
@@ -445,7 +461,7 @@ class UpdateHeaderTestCase(TestCase):
     def test_main(self, argparser_mock):
         self.args.year = "2021"
         self.args.changed = False
-        self.args.licence = "AGPL-3.0-or-later"
+        self.args.license_id = "AGPL-3.0-or-later"
         self.args.files = ["test.py"]
         self.args.directories = None
         self.args.verbose = 0
@@ -465,7 +481,7 @@ class UpdateHeaderTestCase(TestCase):
     def test_main_never_happen(self, argparser_mock, mock_stdout):
         self.args.year = "2021"
         self.args.changed = False
-        self.args.licence = "AGPL-3.0-or-later"
+        self.args.license_id = "AGPL-3.0-or-later"
         self.args.files = None
         self.args.directories = None
         self.args.verbose = 0
