@@ -105,7 +105,7 @@ class SemanticVersionTestCase(unittest.TestCase):
             ("1.0.0", "1.0.0-alpha1"),
             ("1.0.0", "1.0.0-alpha1"),
             ("1.0.0", "1.0.0-beta1"),
-            ("1.0.0+dev1", "1.0.0-dev1"),  # maybe both should be equal
+            ("1.0.0+dev1", "1.0.0-dev1"),
             ("1.0.0+dev1", "1.0.0+dev2"),
             ("1.0.0-alpha1", "1.0.0-beta1"),
             ("1.0.0-alpha1", "1.0.0-alpha1+dev1"),
@@ -121,6 +121,9 @@ class SemanticVersionTestCase(unittest.TestCase):
                 f"{version1} equals {version2}",
             )
 
+        other = None
+        self.assertFalse(Version.from_string("1.0.0") == other)
+
         versions = [
             ("1.0.0", object()),
             ("1.0.0", 1),
@@ -193,6 +196,7 @@ class SemanticVersionTestCase(unittest.TestCase):
 
         versions = [
             ("1.0.0", "abc"),
+            ("1.0.0", None),
         ]
         for version1, version2 in versions:
             self.assertTrue(Version.from_string(version1) != version2)
@@ -206,6 +210,72 @@ class SemanticVersionTestCase(unittest.TestCase):
             with self.assertRaisesRegex(ValueError, "Can't compare"):
                 self.assertFalse(Version.from_string(version1) != version2)
 
+    def test_greater_then(self):
+        versions = [
+            ("1.0.0", "0.9.9999"),
+            ("1.0.1", "1.0.0"),
+            ("1.0.0", "1.0.0-dev1"),
+            ("1.0.0", "1.0.0-alpha1"),
+            ("1.0.0", "1.0.0-alpha1"),
+            ("1.0.0", "1.0.0-beta1"),
+            ("1.0.0", "1.0.0-rc1"),
+            ("1.0.0-alpha1", "1.0.0-dev1"),
+            ("1.0.0-alpha1", "1.0.0-alpha1-dev1"),
+            ("1.0.0-alpha2", "1.0.0-alpha1"),
+            ("1.0.0-beta1", "1.0.0-dev1"),
+            ("1.0.0-beta1", "1.0.0-alpha1"),
+            ("1.0.0-beta1", "1.0.0-beta1-dev1"),
+            ("1.0.0-beta2", "1.0.0-beta1"),
+            ("1.0.0-rc1", "1.0.0-dev1"),
+            ("1.0.0-rc1", "1.0.0-alpha1"),
+            ("1.0.0-rc1", "1.0.0-beta1"),
+            ("1.0.0-rc1", "1.0.0-rc1-dev1"),
+            ("1.0.0-rc2", "1.0.0-rc1"),
+        ]
+        for version1, version2 in versions:
+            self.assertTrue(
+                Version.from_string(version1) > Version.from_string(version2),
+                f"{version1} should be greater then {version2}",
+            )
+
+        versions = [
+            ("1.0.0", "1.0.0"),
+            ("1.0.0", "1.0.0+dev1"),
+            ("1.0.0-dev1", "1.0.0-dev1"),
+            ("1.0.0-dev1", "1.0.0-dev2"),
+            ("1.0.0", "1.0.1"),
+            ("1.0.0-dev1", "1.0.0"),
+            ("1.0.0-dev1", "1.0.0-alpha1"),
+            ("1.0.0-dev1", "1.0.0-beta1"),
+            ("1.0.0-dev1", "1.0.0-rc1"),
+            ("1.0.0+dev1", "1.0.0+dev1"),
+            ("1.0.0+dev1", "1.0.0+dev2"),
+            ("1.0.0-alpha1", "1.0.0-alpha1"),
+            ("1.0.0-alpha1", "1.0.0-beta1"),
+            ("1.0.0-alpha1", "1.0.0-rc1"),
+            ("1.0.0-alpha1", "1.0.0-alpha1+dev1"),
+            ("1.0.0-alpha1-dev1", "1.0.0-alpha1-dev1"),
+            ("1.0.0-alpha1-dev1", "1.0.0-alpha1-dev2"),
+            ("1.0.0-alpha1+dev1", "1.0.0-alpha1+dev2"),
+            ("1.0.0-beta1", "1.0.0-rc1"),
+            ("1.0.0-beta1", "1.0.0-beta1"),
+            ("1.0.0-beta1", "1.0.0-beta1+dev1"),
+            ("1.0.0-beta1-dev1", "1.0.0-beta1-dev1"),
+            ("1.0.0-beta1-dev1", "1.0.0-beta1-dev2"),
+            ("1.0.0-beta1+dev1", "1.0.0-beta1+dev2"),
+            ("1.0.0-rc1", "1.0.0"),
+            ("1.0.0-rc1", "1.0.0-rc1"),
+            ("1.0.0-rc1", "1.0.0-rc1+dev1"),
+            ("1.0.0-rc1-dev1", "1.0.0-rc1-dev1"),
+            ("1.0.0-rc1-dev1", "1.0.0-rc1-dev2"),
+            ("1.0.0-rc1+dev1", "1.0.0-rc1+dev2"),
+        ]
+        for version1, version2 in versions:
+            self.assertFalse(
+                Version.from_string(version1) > Version.from_string(version2),
+                f"{version1} should not be greater then {version2}",
+            )
+
     def test_is_dev_release(self):
         versions = [
             "1.0.0-dev1",
